beamprofiler.niso.characterizing\_parameters.top\_hat\_factor
=============================================================

.. currentmodule:: beamprofiler.niso.characterizing_parameters

.. autofunction:: top_hat_factor